@@ -1,9 +1,12 @@
-__all__ = ('LoanIssuePoint', 'LoanPaymentBodyPoint', 'LoanInterestsChargePoint', 'LoanPaymentInterestsPoint')
+__all__ = ('LoanIssuePoint', 'LoanPaymentBodyPoint', 'LoanInterestsChargePoint', 'LoanPaymentInterestsPoint',
+           'RewardChargePoint',
+           )
 
 from expressmoney.api import *
 from .balances import *
 
 SERVICE = 'accounting'
+APP = 'operations'
 
 
 class OperationContract(Contract):
@@ -29,32 +32,42 @@ class LoanPaymentInterestsCreateContract(OperationContract):
     pass
 
 
+class RewardChargeCreateContract(OperationContract):
+    amount = serializers.DecimalField(max_digits=16, decimal_places=0, min_value=1, max_value=1000000000)
+    is_reverse = serializers.BooleanField()
+
+
 class LoanIssueID(ID):
     _service = SERVICE
-    _app = 'operations'
+    _app = APP
     _view_set = 'loan_issue'
 
 
 class LoanPaymentBodyID(ID):
     _service = SERVICE
-    _app = 'operations'
+    _app = APP
     _view_set = 'loan_payment_body'
 
 
 class LoanInterestsChargeID(ID):
     _service = SERVICE
-    _app = 'operations'
+    _app = APP
     _view_set = 'loan_interests_charge'
 
 
 class LoanPaymentInterestsID(ID):
     _service = SERVICE
-    _app = 'operations'
+    _app = APP
     _view_set = 'loan_payment_interests'
 
 
+class RewardChargeID(ID):
+    _service = SERVICE
+    _app = APP
+    _view_set = 'reward_charge'
+
+
 class LoanIssuePoint(CreatePointMixin, ContractPoint):
-    """Issue loan body (Dt48801 Kt47422)"""
     _point_id = LoanIssueID()
     _create_contract = LoanIssueCreateContract
 
@@ -66,7 +79,6 @@ class LoanIssuePoint(CreatePointMixin, ContractPoint):
 
 
 class LoanPaymentBodyPoint(CreatePointMixin, ContractPoint):
-    """Payment loan body (Dt47423 Kt48801)"""
     _point_id = LoanPaymentBodyID()
     _create_contract = LoanPaymentBodyCreateContract
 
@@ -78,7 +90,6 @@ class LoanPaymentBodyPoint(CreatePointMixin, ContractPoint):
 
 
 class LoanInterestsChargePoint(CreatePointMixin, ContractPoint):
-    """Charge loan interests (Dt48802 Kt71001)"""
     _point_id = LoanInterestsChargeID()
     _create_contract = LoanInterestsChargeCreateContract
 
@@ -90,7 +101,6 @@ class LoanInterestsChargePoint(CreatePointMixin, ContractPoint):
 
 
 class LoanPaymentInterestsPoint(CreatePointMixin, ContractPoint):
-    """Payment loan interests (Dt47423 Kt48809)"""
     _point_id = LoanPaymentInterestsID()
     _create_contract = LoanPaymentInterestsCreateContract
 
@@ -99,3 +109,8 @@ class LoanPaymentInterestsPoint(CreatePointMixin, ContractPoint):
         loan = self._payload.get('analytical')
         related_points.append(P48809BalanceAnalyticalPoint(self._user, loan))
         return related_points
+
+
+class RewardChargePoint(CreatePointMixin, ContractPoint):
+    _point_id = RewardChargeID()
+    _create_contract = RewardChargeCreateContract
